@@ -14,8 +14,7 @@ def counted_list(lines: List[List[str]], number: int, connector: str) -> List[st
     hold = [connector.join(line) for line in lines]
     if len(hold) > number:
         return hold[:number]
-    elif len(hold) < number:
+    if len(hold) < number:
         hold.append(f"You do not have {number} tasks!")
         return hold
-    else:
-        return hold
+    return hold
